#!/bin/bash -e

path_to_source_DMG_image="$1"
path_to_target_DMG_image="$2"
path_to_configuration_file="$3"

configuration_fileName="1cestart.cfg"

function showUsage {
    local scriptName=`basename $1`
    echo -e "\nCommand-line syntax:"
    echo -e "$scriptName [-h|--help] <path_to_source_DMG_image> [path_to_target_DMG_image] [path_to_configuration_file]\n";
    echo -e "Command-line parameters:"
    echo -e "  * -h, --help - open help."
    echo -e "  * [path_to_source_DMG_image] - mandatory - the path to a DMG image of the distribution package that contains the thin or thick client of 1C:Enterprise for macOS.\n"
    echo -e "  * [path_to_target_DMG_image] - optional - the path to the new DMG image of the distribution package. Warning! If the parameter is not specified, the new file name is the original file name with prefix \"out-\".\n"
    echo -e "  Example:"
    echo -e "       Source file name: 1cv8-thin-client-A.B.C.D.dmg"
    echo -e "       Target file name: out-1cv8-thin-client-A.B.C.D.dmg\n\n"
    echo -e "  * [path_to_configuration_file] - optional - the path to the configuration file to be added with the name 1cestart.cfg to the new DMG image. If the parameter is not specified, the utility looks for 1cestart.cfg in the directory specified in the path_to_source_DMG_image parameter.\n"
}

function version_greater() { test "$(printf '%s\n' "$@" | sort -V | head -n 1)" != "$1"; }

[ "$1" == "-h" -o "$1" == "--help"  ] && { showUsage "$0"; exit 0; }
[ `uname -s` == "Darwin" ] || { showUsage "$0"; exit 1; }

# Check DMG image (mandatory)
[ -z "$path_to_source_DMG_image" ] && { showUsage "$0"; exit 2; }
[ ! -f "$path_to_source_DMG_image" ] && { echo "Cannot find the DMG image: \"$path_to_source_DMG_image\"."; showUsage "$0"; exit 3; }

# Check cfg path (optional)
if [ -z "$path_to_configuration_file" ]; then
    path_to_configuration_file="$(dirname ${path_to_source_DMG_image})/$configuration_fileName"
fi
[ ! -f "$path_to_configuration_file" ] && { echo -e "Cannot find the configuration file: \"$(basename $configuration_fileName)\".\n"; showUsage "$0"; exit 4; }

# Check new DMG path (optional)
if [ -z "$path_to_target_DMG_image" ]; then
    path_to_target_DMG_image="$(dirname ${path_to_source_DMG_image})/out-$(basename ${path_to_source_DMG_image})"
fi

# mount DMG-image
MOUNT_POINT=`hdiutil attach "$path_to_source_DMG_image" | grep "/Volumes/"`
MOUNT_DISK=`echo "$MOUNT_POINT" | awk '{ print $1; }'`
VOLUME_PATH=`echo "$MOUNT_POINT" | cut -f3-`
VOLUME_NAME=`echo "$VOLUME_PATH" | cut -d"/" -f3-`

TMP_PATH=`mktemp -d /tmp/v8_tmp_csm_XXXXXX`

cp -aR "$VOLUME_PATH/." $TMP_PATH
cp "$path_to_configuration_file" "$TMP_PATH/$configuration_fileName" && chmod 644 "$TMP_PATH/$configuration_fileName"

# unmount image
hdiutil detach $MOUNT_DISK &>/dev/null

# create output DMG-image
hdiutil create -fs HFS+ -size 500m -volname "$VOLUME_NAME" -scrub -srcfolder "$TMP_PATH" -ov -format UDZO "$path_to_target_DMG_image"
rm -rf "$TMP_PATH"
[ ! -f "$path_to_target_DMG_image" ] && { echo -e "The DMG image was not created: \"$(basename ${path_to_target_DMG_image})\".\n"; exit 5; }
echo "The DMG image is created: \"$(basename ${path_to_target_DMG_image})\".";
echo "You can sign the created DMG image with a digital signature."
